<?php
/**
* © Copyright 2009 IntraHealth International, Inc.
* 
* This File is part of I2CE 
* 
* I2CE is free software; you can redistribute it and/or modify 
* it under the terms of the GNU General Public License as published by 
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful, 
* but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License 
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
* @package ihris-common
* @author Gérard Bisama <gerbis2000@gmail.com>
* @version v3.2
* @since v3.2
* @filesource
*/
/**
* Class iHRIS_Module_GuineeDemographic
*
* @access public
*/


class iHRIS_Module_GuineeDemographic extends I2CE_Module {
	const MIN_AGE_EMPLOYMENT=18;


    /**
     * Return the array of hooks available in this module.
     * @return array
     */
    public static function getHooks() {
        return array(
                'validate_form_demographic' => 'validate_form_demographic'
                );
    }

    /**
     * Perform extra validation for the demographic form form.
     * Check the date of birth that should correspond to 18 years old to be an employee
     * @param I2CE_Form $form
     */
    public function validate_form_demographic( $form ) {
       //print_r($form->birth_date);
        if(isset($form->birth_date))
        {
			$stringDoB=$form->birth_date->day().'/'.$form->birth_date->month().'/'.$form->birth_date->year();
			//print_r("string doB :".$stringDoB);
			$doB= dateTime::createFromFormat('d/m/Y',$stringDoB);
			//print_r(" doB :".$doB);
			//Check if the person is below 18 
			$currentDate= new DateTime();
			$diff=$currentDate->diff($doB);
			$age=$diff->y;
			//print_r("Age :".$age);
			if($age<self::MIN_AGE_EMPLOYMENT)
			{
				$form->setInvalidMessage('birth_date','L\'age doit être supérieur à '.self::MIN_AGE_EMPLOYMENT.' ans à la date d\enregistrement!!', '');
			}
			
		}
		if(isset($form->dependents))
		{
			$dependent=$form->getField('dependents')->getValue();
			if ( I2CE_Validate::checkNumber( $dependent )==false) {
				$form->setInvalidMessage('dependents','Le nombre de personne en charge doit être un entier', '');
			}
		}
    }
    
    
}
# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
